@@ -9,13 +9,20 @@
 #include "kcalutils_debug.h"
 
 #include <QLocale>
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/safestring.h>
+#else
+#include <KTextTemplate/safestring.h>
+#endif
 
 #include <KLocalizedString>
 
 GrantleeKi18nLocalizer::GrantleeKi18nLocalizer()
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     : Grantlee::QtLocalizer()
+#else
+    : KTextTemplate::QtLocalizer()
+#endif
 {
 }
 
@@ -50,10 +57,17 @@ QString GrantleeKi18nLocalizer::processArguments(const KLocalizedString &kstr, c
             str = str.subs(iter->toDouble());
             break;
         case QVariant::UserType:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             if (iter->canConvert<Grantlee::SafeString>()) {
                 str = str.subs(iter->value<Grantlee::SafeString>().get());
                 break;
             }
+#else
+            if (iter->canConvert<KTextTemplate::SafeString>()) {
+                str = str.subs(iter->value<KTextTemplate::SafeString>().get());
+                break;
+            }
+#endif
             // fall-through
             Q_FALLTHROUGH();
         default:
